use anyhow::Context as _;
use base64::prelude::*;

pub async fn update_wiki_from_tree(
    ctx: &crate::Context,
    tree: &crate::tree::Tree,
) -> anyhow::Result<()> {
    let mermaid = tree.to_mermaid(&ctx.repo_url.to_string());
    let wiki_text = format!(
        r##"This page is automatically updated to show the latest and greatest FAFO techtree:

```mermaid
{mermaid}
```
"##
    );
    update_wiki_overview(&ctx, wiki_text)
        .await
        .context("Failed to update the techtree wiki page")?;
    Ok(())
}

pub async fn update_wiki_overview(ctx: &crate::Context, new_body: String) -> anyhow::Result<()> {
    // TODO: Figure out why we get a 404 when the edit was successfull...
    let _ = ctx
        .forgejo
        .repo_edit_wiki_page(
            &ctx.owner,
            &ctx.repo,
            "Home",
            forgejo_api::structs::CreateWikiPageOptions {
                content_base64: Some(BASE64_STANDARD.encode(new_body.as_bytes())),
                message: Some(format!("Updated to latest model at {}", ctx.timestamp)),
                title: Some("Home".to_owned()),
            },
        )
        .await
        .context("Failed editing the wiki page");
    Ok(())
}
